' ********** Copyright 2019 Roku Corp.  All Rights Reserved. **********

' This is the main entry point to the channel scene.
' This function will be called by library when channel is ready to be shown.
sub Show(args as Object)
    ' set theme
    m.top.theme = {
        global: {
            backgroundColor: "0x202020ff"
            OverhangBackgroundColor: "0x000000ff"
        }
    }

    ' create the grid view
    grid = CreateObject("roSGNode", "GridView")
    grid.setFields({
        style: "standard"
        posterShape: "16x9"
        showMetadata: false
    })

    ' specify content handler for root loading model
    content = CreateObject("roSGNode", "ContentNode")
    content.addfields({
        HandlerConfigGrid: {
            name: "CH_GridRoot"
        }
    })

    grid.content = content

    ' use scene component controller to show the grid view
    m.top.ComponentController.callFunc("show", {
        view: grid
    })

    ' check if launched by deep linking
    if args <> invalid 'and args.contentId <> invalid
        ' The launch-time deep linking logic should be implemented here.
        ' In the current test channel this will just show a pop-up dialog.

        messageLines = [
            "This is launch-time deep linking:"
            ""
        ]
        for each key in args
            messageLines.Push(key + ": " + args[key])
        next
        messageLines.Append([
            ""
            "Press 'back' button on your remote to dismiss"
        ])

        dialogConfig = {
            title: "Launch-time deep linking"
            messageLines: messageLines
        }

        m.top.dialog = BuildPopupDialog(dialogConfig)
    end if
end sub

' This is the place where the developer should implement the logic for
' handling deep linking with roInputEvent which doesn't relaunch the channel
sub Input(args as Object)
    ' In case of roInputEvent deep linking args contain the same parameters
    ' as for launch-time deep linking: contentId and mediaType.
    '
    ' Current implementation will just show a pop-up dialog.
    '
    ' The following curl command can be used to test this:
    ' curl -d '' 'http://<your_Roku_IP>:8060/input?mediaType=movie&contentId=test'
  if (args.contentID = "1234" AND args.mediaType="movie")
    messageLines = [
        "This is roInputEvent deep linking:"
        ""
    ]
    for each key in args
        messageLines.Push(key + ": " + args[key])
    next
    messageLines.Append([
        ""
        "Press 'back' button on your remote to dismiss"
    ])

    dialogConfig = {
        title: "roInputEvent deep linking"
        messageLines: messageLines
    }

    m.top.dialog = BuildPopupDialog(dialogConfig)
  end if
end sub

' Helper function for building pop-up dialogs
' @param config [AA] dialog config
' @param config.title [String] dialog title
' @param config.messageLines [Array] array of dialog message lines (strings)
' @return [Node] Dialog node
function BuildPopupDialog(config as Object) as Object
    ' join message lines to a single message using ASCII char 10 (new line)
    msg = ""
    if config.messageLines <> invalid
        for each line in config.messageLines
            ' is it string?
            if line <> invalid and GetInterface(line, "ifString") <> invalid
                ' yes - append to the message
                msg = msg + line + Chr(10)
            end if
        end for
    end if

    ' build the dialog
    dialog = CreateObject("roSGNode", "Dialog")
    dialog.setFields({
        title: config.title
        message: msg
    })

    return dialog
end function
